@@ -1,8 +1,8 @@
-package Pcore::Captcha v0.3.0;
+package Pcore::Captcha v0.3.3;
 
 use Pcore -dist, -class;
 
-with qw[Pcore::API::Response];
+extends qw[Pcore::API::Response];
 
 has captcha => ( is => 'ro', isa => ScalarRef, required => 1 );
 
